==> certmanager-model-v1alpha3-6.3.0-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha3/ACMEAuthorizationFluent.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface ACMEAuthorizationFluent<A extends ACMEAuthorizationFluent<A>> extends Fluent<A>{
  public A addToChallenges(Integer index,ACMEChallenge item);
  public A setToChallenges(Integer index,ACMEChallenge item);
  public A addToChallenges(io.fabric8.certmanager.api.model.acme.v1alpha3.ACMEChallenge... items);
  public A addAllToChallenges(Collection<ACMEChallenge> items);
  public A removeFromChallenges(io.fabric8.certmanager.api.model.acme.v1alpha3.ACMEChallenge... items);
  public A removeAllFromChallenges(Collection<ACMEChallenge> items);
  public A removeMatchingFromChallenges(Predicate<ACMEChallengeBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildChallenges instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ACMEChallenge> getChallenges();
  public List<ACMEChallenge> buildChallenges();
  public ACMEChallenge buildChallenge(Integer index);
  public ACMEChallenge buildFirstChallenge();
  public ACMEChallenge buildLastChallenge();
  public ACMEChallenge buildMatchingChallenge(Predicate<ACMEChallengeBuilder> predicate);
  public Boolean hasMatchingChallenge(Predicate<ACMEChallengeBuilder> predicate);
  public A withChallenges(List<ACMEChallenge> challenges);
  public A withChallenges(io.fabric8.certmanager.api.model.acme.v1alpha3.ACMEChallenge... challenges);
  public Boolean hasChallenges();
  public A addNewChallenge(String token,String type,String url);
  public ACMEAuthorizationFluent.ChallengesNested<A> addNewChallenge();
  public ACMEAuthorizationFluent.ChallengesNested<A> addNewChallengeLike(ACMEChallenge item);
  public ACMEAuthorizationFluent.ChallengesNested<A> setNewChallengeLike(Integer index,ACMEChallenge item);
  public ACMEAuthorizationFluent.ChallengesNested<A> editChallenge(Integer index);
  public ACMEAuthorizationFluent.ChallengesNested<A> editFirstChallenge();
  public ACMEAuthorizationFluent.ChallengesNested<A> editLastChallenge();
  public ACMEAuthorizationFluent.ChallengesNested<A> editMatchingChallenge(Predicate<ACMEChallengeBuilder> predicate);
  public String getIdentifier();
  public A withIdentifier(String identifier);
  public Boolean hasIdentifier();
  public String getInitialState();
  public A withInitialState(String initialState);
  public Boolean hasInitialState();
  public String getUrl();
  public A withUrl(String url);
  public Boolean hasUrl();
  public Boolean getWildcard();
  public A withWildcard(Boolean wildcard);
  public Boolean hasWildcard();
  public A withWildcard();
  public interface ChallengesNested<N> extends Nested<N>,ACMEChallengeFluent<ACMEAuthorizationFluent.ChallengesNested<N>>{
    public N and();
    public N endChallenge();
    
  }
  
}

==> certmanager-model-v1alpha3-6.7.2-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha3/ACMEAuthorizationFluent.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface ACMEAuthorizationFluent<A extends ACMEAuthorizationFluent<A>> extends Fluent<A>{
  public A addToChallenges(int index,ACMEChallenge item);
  public A setToChallenges(int index,ACMEChallenge item);
  public A addToChallenges(io.fabric8.certmanager.api.model.acme.v1alpha3.ACMEChallenge... items);
  public A addAllToChallenges(Collection<ACMEChallenge> items);
  public A removeFromChallenges(io.fabric8.certmanager.api.model.acme.v1alpha3.ACMEChallenge... items);
  public A removeAllFromChallenges(Collection<ACMEChallenge> items);
  public A removeMatchingFromChallenges(Predicate<ACMEChallengeBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildChallenges instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ACMEChallenge> getChallenges();
  public List<ACMEChallenge> buildChallenges();
  public ACMEChallenge buildChallenge(int index);
  public ACMEChallenge buildFirstChallenge();
  public ACMEChallenge buildLastChallenge();
  public ACMEChallenge buildMatchingChallenge(Predicate<ACMEChallengeBuilder> predicate);
  public Boolean hasMatchingChallenge(Predicate<ACMEChallengeBuilder> predicate);
  public A withChallenges(List<ACMEChallenge> challenges);
  public A withChallenges(io.fabric8.certmanager.api.model.acme.v1alpha3.ACMEChallenge... challenges);
  public Boolean hasChallenges();
  public A addNewChallenge(String token,String type,String url);
  public ACMEAuthorizationFluent.ChallengesNested<A> addNewChallenge();
  public ACMEAuthorizationFluent.ChallengesNested<A> addNewChallengeLike(ACMEChallenge item);
  public ACMEAuthorizationFluent.ChallengesNested<A> setNewChallengeLike(int index,ACMEChallenge item);
  public ACMEAuthorizationFluent.ChallengesNested<A> editChallenge(int index);
  public ACMEAuthorizationFluent.ChallengesNested<A> editFirstChallenge();
  public ACMEAuthorizationFluent.ChallengesNested<A> editLastChallenge();
  public ACMEAuthorizationFluent.ChallengesNested<A> editMatchingChallenge(Predicate<ACMEChallengeBuilder> predicate);
  public String getIdentifier();
  public A withIdentifier(String identifier);
  public Boolean hasIdentifier();
  public String getInitialState();
  public A withInitialState(String initialState);
  public Boolean hasInitialState();
  public String getUrl();
  public A withUrl(String url);
  public Boolean hasUrl();
  public Boolean getWildcard();
  public A withWildcard(Boolean wildcard);
  public Boolean hasWildcard();
  public A withWildcard();
  public interface ChallengesNested<N> extends Nested<N>,ACMEChallengeFluent<ACMEAuthorizationFluent.ChallengesNested<N>>{
    public N and();
    public N endChallenge();
    
  }
  
}
